#############################################################################################################################################
#### -------------------------------- LOOCK ET AL 2018 === SERVAL SECR === ------------------------------------------------------------------
#### -High carnivore population density highlights the conservation value of industrialised sites -------------------------------------------
#### General - Session spesfic SECR models
#### Heterogeienity in - i) encounter rate~habitat; ii) sigma ~ session, iii) D~session

#### LOAD PACKAGEs
  library (secr)
  library (plyr)
  library (dplyr)
  library (tidyr)
  library (reshape2)
  library (ggplot2)
#### -------------------------------- GET CAPTURE DATA --------------------------------------------------------------------------------------
#### DATA STRUCTURE
#### sESSION, ANIMALID, OCC, TRAPID
#### Make capture history object
  CH <- read.capthist(captfile ="Cap2.txt", trapfile =c("TL2.txt"), trapcovnames = ("Habitat"), detector = "proximity", fmt = "trapID") 
#### Plot CH
  plot(CH, rad=100, tracks=TRUE)

#### -------------------------------- SUMMARY   ---------------------------------------------------------------------------------------------
#### Capture summaries
    summary(CH)
####	These counts are reported by summary.capthist
####  n number of individuals detected on each occasion
####	u number of individuals detected for the first time on each occasion
####	f number of individuals detected exactly f times
####	M(t+1) cumulative number of individuals detected
####	losses: number of individuals reported as not released on each occasion
####	detections: number of detections, including within-occasion ?recaptures?
####	traps visited: number of detectors at which at least one detection was recorded
####	traps: set number of detectors, excluding any ?not set? in usage attribute of traps attribute    

#### -------------------------------- CLOSURE TESTES       ----------------------------------------------------------------------------------
#### test for closure, see pdf for details,if p>0.05 closure is assumed , 
#### Stanley and Burnham 1999 is calculated in addition to that of Otis et al. 1978
  # These are not really reliable
  closure.test(CH)
#### Estimate N, the size of a closed population, by several conventional 
#### nonspatial capture?recapture methods.
  closedN(CH)
  ?closedN
#### -------------------------------- SECR MODELS          ---------------------------------------------------------------------------------
#### Get buffer to use for SECR analysis
  suggest.buffer(CH)  ## 1.4km, 0.8km, 1.8 km; So we used 3km to encompass all
#### Mask
#### make trap file        
  sec.tr<-read.traps ('TL2.txt', detector='proximity')  
#### make a mask 
#### We use the buffer from the suggest.buffer method - this include much non-habitat, so we created a buffer that remove 
#### non habitat  
  mask.sec <- make.mask(sec.tr,buffer=3000, spacing = 500) 
  plot(mask.sec)
### Get shp that moved non-habitat
  library(maptools)
  ## Get polygon with unsuitable areas removed - UTM 36 S projection
  ser.area <- readShapePoly('Habitat.utm36', delete_null_obj=TRUE)  ##serval habitat area

#### Make it into a mask
  ser.mask2 <- make.mask(traps(CH), spacing = 500,
                           buffer = 3000, type = "polygon",poly = ser.area)
### Plot mask and camera trap points
 
  plot (ser.mask2, ppoly = TRUE)
  plot(traps(CH), add=TRUE)
  
#### SECR models cont.  
#### Test various Detection functions
  Sec.HN<-secr.fit (CH,mask=ser.mask2, detectfn=0)
  Sec.HZ<-secr.fit (CH,mask=ser.mask2, detectfn=1)
  Sec.EX<-secr.fit (CH,mask=ser.mask2, detectfn=2)
  
#### Check with detection function has the most support
#### Choose the detection function with the lowest AIC
#### Our results show hazard rate
  aic.df<-  AIC(Sec.HN, Sec.HZ, Sec.EX)
  write.csv(aic.df, "aic.df.csv")
  write.csv

#### FIT SECR MODELS
#### Mb learned resonse at g0~b (Mod=1)
  Mb.sec <-secr.fit (CH, model = g0~b, mask=ser.mask2, detectfn=1)

#### g0 affected by habitat type (Mod=2)
  Mhab.sec<-secr.fit (CH, model = g0~Habitat, mask=ser.mask2, detectfn=1)
  predict(Mhab.sec,newdata = expand.grid(
    Habitat = factor(c("disturbed", "grass", "grassandwet","wet")),
    session = c("Winter2014","Summer2015","Winter2015")))   
  
#### D affected by season and year (Mod=3)
  Mseason <- secr.fit(CH, model = D ~  session, mask=mask.sec, detectfn=1) 
  print(Mseason)
  
#### Density affected by season and year, and we account for habitat in detection propblablity (Mod=4)
  Mdens.habitat <- secr.fit(CH, model = list(D ~  session, g0~Habitat), mask=ser.mask2, detectfn=1)
  dens.hab <-predict(Mdens.habitat,newdata = expand.grid(
    Habitat = factor(c("disturbed", "grass", "grassandwet","wet")),
    session = c("Winter2014","Summer2015","Winter2015")))  
  coef(Mdens.habitat)
  print(Mdens.habitat)

#### Density affected by season and year, sigma by session, and we account for habitat in detection propblablity (Mod=5)
  Mdens.habitat.ses <- secr.fit(CH, model = list(D ~  session, g0~Habitat, sigma~session), mask=ser.mask2, detectfn=1) 
  print(Mdens.habitat.ses)
  dens.hab.ses <-predict(Mdens.habitat.ses,newdata = expand.grid(
    Habitat = factor(c("disturbed", "grass", "grassandwet","wet")),
    session = c("Winter2014","Summer2015","Winter2015")))  
  
#### Mnull model, where g0=1 (Mod=6)
  M0.sec<-secr.fit (CH, model = g0~1, mask=ser.mask2, detectfn=1)
  print(M0.sec)
  
#### Model selection for all SECR models
  modelresult1<-  AIC(M0.sec,Mb.sec,Mhab.sec, Mseason,Mdens.habitat,Mdens.habitat.ses)
  write.csv(modelresult1, "modelresult.df.2018-03-07.csv")
 
#### Model average for  top models
  test7<-model.average(Mhab.sec, Mdens.habitat, newdata = expand.grid(
    Habitat = factor(c("disturbed", "grass", "grassandwet","wet")),
    session = c("Winter2014","Summer2015","Winter2015")))
 
  model.average(Mhab.sec, Mdens.habitat, betanames = c("D","g0","sigma")) 
  model.average(Mhab.sec, Mdens.habitat) 
  
#### coerse into data frame for plotting and summary for exsport
  test8 <-as.data.frame(test7)
  
  test8 <- cbind(Row.Names = rownames(test8), test8)
  
  rownames(test8) <- NULL
  
  test9<-test8 %>%
    separate(Row.Names, c("Habitat", "Session"), ",")
  
  test10<-test9 %>%
    separate(Habitat, c("Habitat1", "Habitat"), "=")
  
  test11<-test10 %>%
    separate(Session, c("Session2", "Session"), "=")
  
  drops <- c("Habitat1","Session2")
  test11 <-test11[ , !(names(test11) %in% drops)]
  
  write.csv(test11, "SasolSECRresult.2018-03-07.csv")
  
#### plotting
  
  test11$Session <- as.factor(test11$Session)
  
  test11$Session <- factor(test11$Session, levels = c("Winter2014", "Summer2015", "Winter2015"))
  
  ses.plot2<- ggplot(test11, aes(x=Session, y=estimate.D*10000)) + 
    geom_errorbar     (aes(ymin=lcl.D*10000, ymax=ucl.D*10000), colour="black", width=0.2, size=1.5, lty="solid") +
    geom_point        ( size=5, pch=15)+
    scale_y_continuous(name="Density (Ind/100km2)", limits=c(0, 200))+
    xlab("Density")+
    theme (axis.text=element_text(size=20),
           axis.title=element_text(size=20,face="bold"),
           panel.background = element_rect(fill = "White", colour = "black", size = 1))
  
  test11$Habitat<-revalue(test11$Habitat, c("disturbed"="Distrubed", "grass"="Grassland", "grassandwet"="Grass & wetland", "wet"="Wetland"))
  
  
  g0.plot2<- ggplot(test11, aes(x=Habitat, y=estimate.g0)) + 
    geom_errorbar(aes(ymin=lcl.g0, ymax=ucl.g0), colour="black", width=0.2, size=1.5, lty="solid") +
    geom_point( size=5, pch=15)+
    scale_y_continuous(name="Encounter rate (g0)", limits=c(0, 0.50))+
    xlab("Habitat type")+
    theme(axis.text=element_text(size=20),
          axis.title=element_text(size=20,face="bold"),
          axis.title.x = element_text("Habitat type"),
          panel.border = element_rect(linetype = "dashed", fill = NA))
  
#### Plot on one panel plot  
  library("cowplot")
  plot_grid(ses.plot2, g0.plot2,
            labels = c("(a)", "(b)"),
            ncol = 2, nrow = 1) 

#### -------------------------------- Live trapping data   -----------------------------------------------------------------------
  library(spData)
  library(dplyr)
  library(readxl)
  library(scales)
  library(ggplot2)
  detach("package:plyr", unload=TRUE) 
  #Capture_data <- read_excel("LiveTrapping.2018-03-08.xlsx", sheet = "Trapping Data R")
  
  Capture_data1 <- read.csv("Live Captures 2018-03-23.csv")
  
  head(Capture_data)
  
  LT.y    <- Capture_data[,1:9]
  
  LT      <- as.data.frame(LT[ which(LT$open=='Y'), ])
  
  LT$date <- as.Date(LT$date)
  
  LT1     <- dplyr::group_by(LT, Trap)
  
  LT2     <- dplyr::summarise(LT1, count = n(), TS = sum(trapped, na.rm = T))
  
  LT.year <- dplyr::group_by(LT,Trap, Date2, year)
  
  LT.y    <- dplyr::summarize(LT.year, count = n(), TS = sum(trapped, na.rm = T))
  
  LT.year <- dplyr::mutate(LT.y, T.S = TS/count)
  
  LT.year$Date2 <- factor(LT.year$Date2, levels = c("June", "September", "November", "December"))
  
  means <- aggregate(T.S ~  Date2, LT.year, mean)
  
  p       <- ggplot(LT.year, aes(x = Date2, y = T.S, fill=Date2))+
    facet_grid(~year,scales = "free_x", space="free_x")+
    geom_boxplot(aes(group=Date2))+ geom_jitter(width = 0.2) +
    labs(x = "Date", y = "Trap success (captures per trap night)")+
    theme_bw() +
    theme(legend.position="none")+
    stat_summary(fun.y=mean, colour="darkred", geom="point", 
                 shape=22, size=6,show.legend =  FALSE) 
  

  p
  ggsave("p.pdf", width = 16, height = 12, units = "cm") 
  
 
#### -------------------------------- SUP DATA FOR PAPER - MAP OF MASK AREA -----------------------------------------------------------------
#### libraries for plotting  
  library (ggmap       , quietly = T)
  library (ggplot2     , quietly = T)
  library (rgdal       , quietly = T)
  library (RgoogleMaps , quietly = T)
  library (raster)
  
#### first transform ser.area2 into lat long - this is the excluded area  
#### Define CRS when importing
  ser.area2 <- readShapePoly('Habitat.utm36', delete_null_obj=TRUE, proj4string=CRS("+init=EPSG:32736"))
#### tranform CRS
  ser.area3 <- spTransform(ser.area2, CRS("+proj=longlat +datum=WGS84"))
#### Fortify data for plotting in ggmap
  data <- fortify(ser.area3)
#### Get mask points - use only one session, they are all the same
  mask.points  <-ser.mask2$Summer2015
  mask.points  <-as.data.frame(mask.points)
  coordinates (mask.points) <- c("x", "y")
  proj4string (mask.points) <- CRS("+init=EPSG:32736")
  mask.points2 <- spTransform(mask.points, CRS("+proj=longlat +datum=WGS84"))
  data2        <- as.data.frame(mask.points2)
#### traps
  t.xy<- as.data.frame(sec.tr)
  coordinates(t.xy) <- c("x", "y")
  proj4string(t.xy) <- CRS("+init=EPSG:32736")
  t.xy2 <- spTransform(t.xy, CRS("+proj=longlat +datum=WGS84"))
  data3<- as.data.frame(t.xy2)
  
#### grap a sattelite image; i used the centre of site as location
  location <- get_map(location = c(lon = 29.1562, lat = -26.5491), zoom = 12,  maptype="satellite", crop=FALSE)
 
### plot
  ggmap(location, zoom = 12, maptype = 'satellite') +
    geom_polygon(aes(x = long, y = lat, group=group), data = data,
                 colour = 'black', fill = 'grey', alpha = .2, size = .8)+
    geom_point(aes(x = x, y = y), data = data2,
               colour = 'black', fill = 'black', alpha = 1, size = 1)+
    geom_point(aes(x = x, y = y), data = data3,
               colour = 'yellow', fill = 'black', alpha = 0.5, size = 3)
  
#### -------------------------------- SUP DATA ACCU CURVES --------------------------------------------------------------------------------
#### Summer 2015
  CH$Summer2015
  Sum2015 <- data.frame(counts(CH$Summer2015, counts = "M(t+1)"))
  Sum2015 <- as.matrix(Sum2015)
  Sum2015 <- matrix(Sum2015, ncol = ncol(Sum2015), dimnames = NULL)
  Sum2015 <- data.frame(seq(1:41), Sum2015[1,])
  Sum2015 <- Sum2015[-41,]
  colnames(Sum2015) <- c("Days", "Ind")
  plot(Sum2015$Days, Sum2015$Ind, main = "Sum2015")
  
#### Winter2014
  CH$Winter2014
  Win2014<- data.frame(counts(CH$Winter2014, counts = "M(t+1)"))
  Win2014 <- as.matrix(Win2014)
  Win2014 <- matrix(Win2014, ncol = ncol(Win2014), dimnames = NULL)
  Win2014 <- data.frame(seq(1:41), Win2014[1,])
  Win2014 <- Win2014[-41,]
  colnames(Win2014) <- c("Days", "Ind")
  plot(Win2014$Days, Win2014$Ind, main = "Win2014")
  
#### Winter 2015
  CH$Winter2015
  Win2015<- data.frame(counts(CH$Winter2015, counts = "M(t+1)"))
  Win2015 <- as.matrix(Win2015)
  Win2015 <- matrix(Win2015, ncol = ncol(Win2015), dimnames = NULL)
  Win2015 <- data.frame(seq(1:40), Win2015[1,])
  colnames(Win2015) <- c("Days", "Ind")
  plot(Win2015$Days, Win2015$Ind, main = "Win2015")
  
#### Merge data frames  
  m14.15  <-  merge(Win2014,Win2015, by = "Days", all = TRUE)
  m.all   <-  merge(m14.15, Sum2015, by = "Days", all = TRUE)
  colnames(m.all) <- c("Trap.Days", "Winter2014", "Winter2015", "Summer2015")
#### Plot on graph - accumulation of ind over trapping nights  
  
  ggplot(data = m.all) +
    geom_point(aes(Trap.Days*35, Winter2014, color = "Winter2014")) +
    geom_point(aes(Trap.Days*35, Winter2015, color = "Winter2015")) +
    geom_point(aes(Trap.Days*35, Summer2015, color = "Summer2015")) +
    xlim(0,1500)+
    ylim(0,40)+
    ylab(label="Number of new serval") + 
    xlab("Trap days")+
    labs(color = "")
  
#### -------------------------------- ANALYSIS END      --------------------------------------------------------------------------------------
# Plot live trapping figure
  
library(spData)
library(dplyr)
library(readxl)
library(scales)
library(ggplot2)
Capture_data <- read_excel("Capture data LS.xlsx", sheet = "Trapping Data R")
head(Capture_data)

LT<-Capture_data[,1:9]

LT <- as.data.frame(LT[ which(LT$open=='Y'), ])

LT$date <- as.Date(LT$date)

LT1 <- group_by(LT, Trap)

LT2 <- summarize(LT1, count = n(), TS = sum(trapped, na.rm = T))

LT.year <- group_by(LT,Trap, Date2, year)

LT.y <- summarize(LT.year, count = n(), TS = sum(trapped, na.rm = T))

LT.year<-mutate(LT.y, T.S = TS/count)

LT.year$Date2 <- factor(LT.year$Date2, levels = c("June", "September", "November", "December")) # convert months to factor in correct order

p <- ggplot(LT.year, aes(x = Date2, y = T.S, fill=Date2))+
  facet_grid(~year,scales = "free_x", space="free_x")+
  geom_boxplot(aes(group=Date2))+ geom_jitter(width = 0.2, alpha = 0.5) +
  labs(x = "Date", y = "Trap success (captures per trap night)")+
  theme_bw() +
  theme(legend.position="none") +
  stat_summary(fun.y="mean", geom="point", shape=23, size=3, fill="white", alpha = 0.8) +
  stat_summary(fun.data = give.n, geom = "text", size = 5, position="fill")
p
ggsave("p.png", width = 16, height = 12, units = "cm")
  
  
  
  
  
  
    